<!--产品分类 -->
<template>
    <page-container>
    <!-- <pro-search
            :columns="query.columns"
            target="category"
            @search="handleSearch"
                                /> -->
        <j-search :columns="searchs" @search="handleSearch" :type="value" />
        <FullPage>
            <JProTable ref="tableRef" :columns="table.columns" :request="queryStore" model="TABLE"
                v-model:expandedRowKeys="expandedRowKeys" 
                :scroll="{ y: 550 }" 
                :defaultParams="{
                    paging: false,
                    sorts: [
                        { name: 'sortIndex', order: 'asc' },
                        {
                            name: 'createTime',
                            order: 'desc',
                        },
                    ],
                }" 
                :params="params" 
                :loading="tableLoading">
                <template #headerTitle>
                    <j-space>
                        <PermissionButton type="primary" @click="add" hasPermission="device/Category:add">
                            <template #icon>
                                <AIcon type="PlusOutlined" />
                            </template>
                            新增库房
                        </PermissionButton>
                        <!-- <PermissionButton danger @click="onDelete" hasPermission="device/Category:delete">
                            <template #icon>
                                <AIcon type="DeleteOutlined" />
                            </template>
                            删除
                        </PermissionButton> -->
                    </j-space>
                </template>
                <template #action="slotProps">
                    <j-space>
                        <template v-for="(i, index) in getActions(slotProps, 'table')" :key="i.key">
                            <PermissionButton :disabled="i.disabled" :popConfirm="i.popConfirm"
                                :hasPermission="'device/Category:' + i.key" :tooltip="{
                                    ...i.tooltip,
                                }" @click="i.onClick" type="link" style="padding: 0px" :danger="i.key === 'delete'">
                                <template #icon >
                                    <AIcon :type="i.icon" />
                                </template>
                            </PermissionButton>
                            <!-- <j-divider v-if="actionLength - 1 != index" type="vertical" /> -->
                        </template>
                    </j-space>
                </template>
            </JProTable>
        </FullPage>
        <!-- 新增和编辑弹窗 -->
        <ModifyModal ref="modifyRef" :formData="currentForm" :title="title" :isAdd="isAdd" :isChild="isChild"
            @refresh="refresh" />
        <j-modal :visible="visible" title="确认删除" @ok="handleOk" @cancel="handleCancel" :confirmLoading="confirmLoading">
            <p class="delete_content"><img :src="getImage('/question-mark.png')" alt=""></p>
            <p class="delete_content title">确认删除这条信息吗？</p>
            <p class="delete_content desc">删除后无法恢复，确定要删除吗？</p>
        </j-modal>
    </page-container>
</template>
<script lang="ts" name="Category" setup>
import { getImage } from '@/utils/comm';
import { queryStore, deleteStore } from '@/api/warehouse/store';
import type { ActionsType } from '@/components/Table/index';
import ModifyModal from './components/modifyModal/index.vue';
import { message } from 'jetlinks-ui-components';
const expandedRowKeys = ref<any>([]);
const tableRef = ref<Record<string, any>>({});
const modifyRef = ref();
const dataSource = ref<any>([]);
const currentForm = ref({});
const title = ref('');
const isAdd = ref(0);
const isChild = ref(0);
const tableLoading = ref(false);
let params = ref();
let actionLength = ref<number>(0);
const selectedKeys = ref<string[]>([]);
const visible = ref<boolean>(false);
const confirmLoading = ref<boolean>(false);
const value = ref('object');
const searchs = ref<any>([
    {
        title: '',
        dataIndex: 'name',
        search: {
            type: 'string',
            componentProps: {
                placeholder: '请输入关键字',
            },
            defaultValue: '123123',
        },
    }
]);

const onSearch = (e: any) => {
    console.log(e)
};

const onDelete = () => {
    visible.value = true;
}
/**
 * 删除确认
 * @param e 
 */
const handleOk = (e: MouseEvent) => {
    console.log(e);
    confirmLoading.value = true;

    setTimeout(() => {
        confirmLoading.value = false;

        visible.value = false;
    }, 1000);
};
/**
 * 删除取消
 * @param e 
 */
const handleCancel = (e: MouseEvent) => {
    console.log(e);
    visible.value = false;
};
/**
 * 复选框选中回调
 * @param keys 
 */
const onSelectChange = (keys: string[]) => {
    selectedKeys.value = [...keys];
};
/**
 * 搜索
 */
const handleSearch = (e: any) => {
    let arr = [];
    for(let key in e) {
        arr.push(key + "=" + e[key]);
    }
    
    params.value = {where: arr.join(" and ")};
    expandedRowKeys.value = [];
};
/**
 * 操作栏按钮
 */
const getActions = (
    data: Partial<Record<string, any>>,
    type: 'table',
): ActionsType[] => {
    if (!data) return [];
    const actions = [
        {
            key: 'update',
            text: '编辑',
            tooltip: {
                title: '编辑',
            },
            icon: 'EditOutlined',
            onClick: async () => {
                title.value = '编辑单位信息';
                isAdd.value = 2;
                currentForm.value = data;
                nextTick(() => {
                    modifyRef.value.show(data);
                });
            },
        },
        {
            key: 'delete',
            text: '删除',
            tooltip: {
                title: '删除',
            },
            icon: 'DeleteOutlined',
            popConfirm: {
                title: '确认删除?',
                okText: ' 确定',
                cancelText: '取消',
                onConfirm: async () => {
                    const resp = await deleteStore(data.id);
                    if (resp.status === 200) {
                        message.success('操作成功！');
                        tableRef.value.reload();
                    } else {
                        message.error('操作失败！');
                    }
                },
            },
        },
    ];
    actionLength.value = actions.length;

    return actions;
};

const table = reactive({
    columns: [
        {
            title: '库房名称',
            dataIndex: 'name',
            key: 'name',
        },
        {
            title: '所属单位',
            dataIndex: 'institution.name',
            key: 'institution',
        },
        {
            title: '所属区域',
            dataIndex: 'region.name',
            key: 'region',
        },
        {
            title: '设备数量',
            dataIndex: 'units',
            key: 'units',
        },
        {
            title: '操作',
            key: 'action',
            fixed: 'right',
            ellipsis: true,
            scopedSlots: true,
            // width: 125,
        },
    ],
    /**
     * 添加产品分类
     */
    add: async () => {
        title.value = '新增单位';
        isAdd.value = 0;
        isChild.value = 3;
        nextTick(() => {
            modifyRef.value.show(currentForm.value);
        });
    },
    /**
     * 刷新表格数据
     */
    refresh: () => {
        tableRef.value.reload();
    },
});
const { add, columns, refresh } = toRefs(table);
/**
 * 初始化
 */
</script>
<style scoped lang="less">
:deep(._jtable-body_1eyxz_1 ._jtable-pagination_1eyxz_43) {
    margin-top: 20px;
    display: none;
    justify-content: flex-end;
}

.delete_content {
    text-align: center;

    &.title {
        font-size: 18px;
        font-family: PingFang SC-Medium, PingFang SC;
        font-weight: 500;
        color: #333333;
        line-height: 16px;
    }

    &.desc {
        font-size: 14px;
        font-family: PingFang SC-Regular, PingFang SC;
        font-weight: 400;
        color: #4F4F4F;
        line-height: 22px;
    }

    img {
        width: 40px;
        height: 40px;
    }
}
</style>
